# Alchemizer

A meta-framework to facilitate development of frameworks using identity map and unit of work patterns.

The name is a nod to [SQLAlchemy](https://github.com/sqlalchemy/sqlalchemy) and [RuneScape](https://runescape.wiki/w/Alchemiser).
